#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

# To reduce size cups dev files deleted after install and before compile
export CFLAGS='-flto=auto -Os -pipe -march=armv8-a+crc -mtune=cortex-a72   '
export CXXFLAGS='-flto=auto -Os -pipe -fno-exceptions -fno-rtti -march=armv8-a+crc -mtune=cortex-a72  '
export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig:/usr/lib/pkgconfig
echo $CFLAGS && echo $CXXFLAGS

P=epdfview
V=0.1.8
SRC=$P-$V
PATCH=$P-$V-fixes-2.patch
USER=`cat /etc/sysconfig/tcuser`
LIST="poppler-dev compiletc squashfs-tools wget gtk2-dev "
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

cd /usr/local/lib
rm -rf *.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/plugin/*.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/*.la
rm -rf gprofng/*.la 
rm -rf python3.8/site-packages/*.la
rm -rf pkcs11/*.la
rm -rf cairo/*.la
rm -rf gtk-2.0/modules/*.la
rm -rf gtk-2.0/2.10.0/printbackends/*.la
rm -rf gtk-2.0/2.10.0/immodules/*.la
rm -rf gtk-2.0/2.10.0/engines/*.la
rm -rf imlib2/loaders/*.la
rm -rf imlib2/filters/*.la
rm -rf gdk-pixbuf-2.0/2.10.0/loaders/*.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/plugin/libcp1plugin.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/plugin/libcc1plugin.la
rm -rf gcc/armv7l-unknown-linux-gnueabihf/12.2.0/liblto_plugin.la
rm -rf pulseaudio/libpulsedsp.la
rm -rf pulseaudio/libpulsecore-13.0.la
rm -rf pulseaudio/libpulsecommon-13.0.la
rm -rf libv4l/v4l2convert.la
rm -rf libv4l/v4l1compat.la
rm -rf libv4l/plugins/libv4l-mplane.la
cd /tmp
rm -rf /usr/lib/*.la
find / -name *.la

# reduce size delete cups-devs
rm -rf /usr/local/include/cups
rm -rf /usr/local/lib/pkgconfig/cups.pc
rm -rf /usr/local/bin/cups-config

su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://github.com/JotaRandom/$P/archive/refs/tags/$V.zip \
http://www.linuxfromscratch.org/patches/blfs/svn/$PATCH "  $USER
unzip $V.zip
cd $SRC
patch -Np1 < ../$PATCH
# only 1 of 4 patches work others already patched 
./configure --prefix=/usr/local --build=aarch64-unknown-linux-gnu
make -j4 # 20 secs
make install-strip DESTDIR=/tmp/$P 
cd /tmp

# locale
#########
mkdir -p $P-locale/usr/local/share
mv $P/usr/local/share/locale $P-locale/usr/local/share

# main
####### reduce size first
rm -rf $P/usr/local/share/man
rm -rf $P/usr/local/share/epdfview/extra
# ^ removes epdfsync, bsd.latexmkrc, dot.latexmkrc & epdfview.svg
rm -rf $P/usr/local/share/epdfview/ui/epdfview-ui-print.xml

mkdir -p $P/usr/local/share/doc/$P
echo 'GPL v2' > $P/usr/local/share/doc/$P/COPYING

DESK=$P/usr/local/share/applications/$P.desktop
sed 's|Viewer;Office;GTK;Graphics;Viewer|Applications;System|' -i $DESK
sed 's|/usr/share/epdfview/extra/epdfview.svg|epdfview.png|' -i $DESK
sed 's|ePDFViewer|epdfview|g' -i $DESK
mkdir -p $P/usr/local/share/pixmaps
cp $P/usr/local/share/epdfview/pixmaps/icon_epdfview-48.png \
$P/usr/local/share/pixmaps/$P.png
echo 'X-FullPathIcon=/usr/local/share/pixmaps/epdfview.png' >> $DESK

# TCZ them
###########
LIST2="$P $P-locale "
for Z in $LIST2
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo "Title:          epdfview-locale.tcz
Description:    language files
Version:        0.1.8
Author:         Emma's Software, Jordi Fita & Pablo Lezaeta
Original-site:  https://github.com/JotaRandom/epdfview
Copying-policy: GPL v2
Size:           112K
Extension_by:   aus9
Tags:           pdf
Comments:       untested by me

Change-log:     2023/09/03 v 0.1.8 on 14.x
Current:        2023/09/03    " > $P-locale.tcz.info
echo 'epdfview.tcz' > $P-locale.tcz.dep

echo "Title:          epdfview.tcz
Description:    GTK2 PDF viewer 
Version:        0.1.8
Author:         Emma's Software, Jordi Fita & Pablo Lezaeta 
Original-site:  https://github.com/JotaRandom/epdfview
Copying-policy: GPL v2
Size:           52K
Extension_by:   aus9
Tags:           pdf 
Comments:       No updates for 6 years. Use a web browser, not this
                for printing. Opened my password locked test sample
                
Change-log:     2023/09/03 v 0.1.8 on 14.x
Current:        2023/09/03 " > $P.tcz.info

readelf -d $P/usr/local/bin/* | grep 'NEEDED'
#[libgthread-2.0.so.0][libglib-2.0.so.0][libgobject-2.0.so.0][libgio-2.0.so.0]
# glib2 choose cairo pango gtk2
#[libpoppler-glib.so.8]poppler
#[libgdk-x11-2.0.so.0][libgtk-x11-2.0.so.0]gtk2
#[libpangocairo-1.0.so.0][libpango-1.0.so.0][libpangoft2-1.0.so.0]pango gtk2
#[libcairo.so.2]cairo pango gtk2
#[libgdk_pixbuf-2.0.so.0]gdk-pixbuf gtk2
#[libharfbuzz.so.0]harfbuzz gtk2
#[libatk-1.0.so.0]atk gtk2
#[libfontconfig.so.1]fontconfig choose cairo gtk2
#[libfreetype.so.6]freetype "

echo 'gtk2.tcz
poppler.tcz ' > $P.tcz.dep


